

%macro p10_earnings(infile , x, k=180); 

**********************************************************
* 10 ptf ; 
********************************************************* ; 
proc sort data  =  &infile out = _raws ; by ex rdate ; run ; 

proc univariate data=_Raws  noprint;
  var &x ;
  where ex = 'USA' and exchcd  = 1 ; 
  by ex rdate ;
  output out=NYSE pctlpts = 10 20 30 40 50 60 70 80 90 pctlpre=P;run; 

proc univariate data=_Raws  noprint;
  var &x ;
  where ex ^= 'USA' ; 
  by ex rdate;
  output out=NYSEint pctlpts = 10 20 30 40 50 60 70 80 90 pctlpre=P;run; 


data NYSE ; set NYSE NYSEint ; proc sort ; by ex rdate ; 
proc delete data = NYSEint ; run ; 


data  temprr(where = (ind >0)) ; 
	merge  _Raws NYSE ; 
	by ex rdate ; 
	if &x ^=. then do ; 
	ind = 1 ; 
	if &x >= P10 then ind = 2  ;
	if &x >= P20 then ind = 3  ;
	if &x >= P30 then ind = 4  ;
	if &x >= P40 then ind = 5  ;
	if &x >= P50 then ind = 6  ;
	if &x >= P60 then ind = 7  ;
	if &x >= P70 then ind = 8  ;
	if &x >= P80 then ind = 9  ;
	if &x >= P90 then ind = 10 ;
	end ; 
	drop P1-P99 ;
run ; 



***************************************************************************
*              compute weights ;
************************************************************************** ;

proc sql ; 
create table dates as select distinct
rdate as refresh_date format yymmddn8. label 'refresh_date', b.date as rdate format yymmddn8. label 'rdate' , c.date
from (select distinct rdate from temprr) a , crsp.msi b , crsp.msi c
where  -60 <=intck('month',a.rdate, b.date) <&k
and  0 < intck('month',b.date, c.date) = 1  order by refresh_date , date ; 


create view temprr2 as select distinct
a.vid , b.refresh_date , b.rdate , b.date ,  ind , ex
from temprr a , dates b
where a.rdate = b.refresh_date ; 


create  table w as select distinct
a.vid , a.refresh_date , a.rdate , a.date ,  a.ex ,  ind , me / sum(me) as w format best12.
from temprr2 a , rsch.msf  b
where a.vid = b.vid and a.rdate = b.date and b.me >0 
group by  a.ex , ind , refresh_date  , a.rdate , b.date, a.date ; 



***************************************************************************
*              returns
*************************************************************************** ;

proc sql ; 
create table ptfreta as select distinct
a.ex , ind , a.refresh_date , a.rdate , b.date, sum(w*ret) as ret, sum(w*retx) as retx
from w a , ind.dividends(keep = vid date ret retx)  b
where a.vid = b.vid and a.date = b.date
group by  a.ex , ind , refresh_date  , a.rdate , b.date
order by  ex  ,  ind , refresh_date  , a.rdate , b.date ; 


create table ptfearnings as select distinct
a.ex , ind , a.refresh_date , a.rdate , a.date, sum(w*ep) as ep
from w a , temp.xfa(keep = vid rdate ep)  b
where a.vid = b.vid and 0<=intck('month',b.rdate, a.rdate) <= 12
group by  a.ex , ind , refresh_date  , a.rdate , a.date
order by  ex  ,  ind , refresh_date  , a.rdate , a.date ; 

create table ptfret as select distinct
a.*, b.ep label 'earnings to price (ep)' 
from ptfreta a, ptfearnings b
where a.ex=b.ex and a.ind=b.ind and a.refresh_date=b.refresh_date and a.rdate=b.rdate and a.date=b.date
order by  ex  ,  ind , refresh_date  , a.rdate , a.date ; 

drop view temprr2 ;
drop table dates ; 

***************************************************************************
*            LS 
*************************************************************************** ;

data L ; set ptfret ; where ind = 10 ; L = ret ; L2 =retx; L3=ep; drop ret retx ind ep; run ; 
data S ; set ptfret ; where ind = 1  ; S = ret ; S2 =retx; S3=ep; drop ret retx ind ep; run ; 

data ls ; merge L S ; by ex refresh_date rdate date ;
ret = L-S ; 
retx = L2- S2 ;
ep = L3 - S3;
format ret 11.6 ; 
ind = 11 ; 
drop L S L2 S2 L3 S3; 

proc append data = ls base = ptfret ; run ; 

proc delete data = L ls S ; run ; 

 


***************************************************************************
*            Global 
*************************************************************************** ;



data P10_earnings_&x ; 
set ptfret ;
xret = ret ; 
if ind =11   then xret = ret ; 
format xret 11.6 ; 
run ; 


data p10_w;
set w;
run;

proc sql ; drop table w , u ,P10 ,  temprr , _raws , nyse , ptfret ; quit ;
 
%mend ; 
