

%macro portfolio(xvar = ,
infile = umd,
retfile = rsch.msf,
datevar = rdate ,
k = 1 ,
sizevar = me ,
fffile = rsch.msi  ,
sizebreak = 80 ,
wind = 1 , p1 = 1 ,p2 = 99 ,
uscondsort = 0 , 
keeplc = 0 ,keepsc = 0 ,keepl  = 0 ,keeps  = 0 , keep_all = 0,
keepw = 1 ,
fill = 1 , 
keepsmb = 0); 


***************************************************************************
*                sort data      
************************************************************************** ; 
proc sort data = &infile out = temprr ;  by ex &datevar ; 
where ex is not missing and &datevar is not missing and &sizevar is not missing 
and &xvar is not missing ; 
run ; 

***************************************************************************
*               windosorize  
************************************************************************** ; 

%if  &wind = 1 %then %do ; 
%put "Windsorize at &p1 and &p2 level"; 
%windsor(dataset =  temprr, var= &xvar, byvar = ex &datevar , p1 = &p1 , p2 = &p2) ; 
proc sort data = temprr  ;  by ex &datevar ; run ;
%end ;

***************************************************************************
*  First 1: sort on size 
************************************************************************** ; 

proc sort data =  temprr out = temprr ;  by ex &datevar ; run ; 

* US size sort: NYSE-based ;  
proc univariate data=temprr  noprint;
  var &sizevar;
  where ex = 'USA' and exchcd  = 1 ; 
  by ex &datevar;
  output out=NYSE pctlpts = 50 pctlpre=P;run; 

* ex US size sort: top 20% by country ; 
proc univariate data=temprr  noprint;
  var &sizevar;
  where ex ^= 'USA' ; 
  by ex &datevar;
  output out=NYSE2 pctlpts = &sizebreak pctlpre=P;run; 

*merge breakpoints ; 
data NYSE ; 
set NYSE NYSE2(rename = (P&sizebreak = P50)) ; 
proc sort nodupkey ; 
by ex &datevar ; run ; 

*size ; 
data  temprr ; 
	merge  temprr nyse ; 
	by ex &datevar ; 
	if &sizevar >0 then do ; 
	nyse_size = 1 ; 
	if &sizevar >= P50 then nyse_size = 2 ;
	end ; 
	drop P50 ;
run ; 


***************************************************************************
*                   rank on second variable; 
************************************************************************** ;
proc sort data = temprr ; by ex &datevar  nyse_size ; run ; 

* US sort: nyse based (independent sort);   
%if &uscondsort = 0 %then %do ; 
proc univariate data= temprr noprint;
  var &xvar;
  where ex = 'USA' and exchcd  = 1 ; 
  by ex &datevar;
  output out=NYSE pctlpts = 30 70 pctlpre=P;run; 
  
*merge breakpoints ; 
data NYSEa ; set NYSE ; nyse_size = 1 ; run ; 
data NYSEb ; set NYSE ; nyse_size = 2 ; run ; 

data NYSE ;  set NYSEa NYSEb  ; proc sort nodupkey ; 
by ex &datevar nyse_size; 

proc delete data = NYSEa NYSEb ; run ; 

%end ; 

*US sort, conditional ; 
 %if &uscondsort = 1 %then %do ; 
proc univariate data= temprr noprint;
  var &xvar;
  where ex = 'USA' and exchcd  = 1 ; 
  by ex &datevar nyse_size;
  output out=NYSE pctlpts = 30 70 pctlpre=P;run; 
%end ; 

* International: Conditional sort ;  
proc univariate data= temprr noprint;
  var &xvar; 
  where  ex ^= 'USA' ; 
  by ex &datevar nyse_size;
  output out=NYSEint pctlpts = 30 70 pctlpre=P;run; 

*merge breakpoints ; 
data NYSE ; set NYSE NYSEint;  
proc sort nodupkey ; 
by ex &datevar nyse_size; run ; 

* Assign to ptf ; 
data temprr(keep = vid &datevar nyse_size ex BMR)  ; 
	merge temprr nyse ; 
	by ex &datevar nyse_size; 
	if &xvar ^=. and nyse_size >0 then do ; 
	BMR = 1 ; 
	if &xvar >  P30 then BMR = 2 ;
	if &xvar >= P70 then BMR = 3 ;
	drop P30 P70  ; 
	end ; 
run ; 



***************************************************************************
*              compute weights ;
************************************************************************** ;

proc sql ; 
create table dates as select distinct
&datevar as refresh_date format yymmddn8. label 'refresh_date', b.date as rdate format yymmddn8. label 'rdate' , c.date
from (select distinct &datevar from temprr) a , crsp.msi b , crsp.msi c
where  0<=intck('month',a.&datevar, b.date)<&k 
and  0<=intck('month',b.date, c.date)=1  order by refresh_date , date ; 

create view temprr2 as select distinct
a.vid , b.refresh_date , b.rdate , b.date , nyse_size ,  BMR , ex
from temprr a , dates b
where a.&datevar = b.refresh_date ; 

create  table w as select distinct
a.vid , a.refresh_date , a.rdate , a.date ,  a.ex , nyse_size ,  BMR , me / sum(me) as w format best12.
from temprr2 a , &retfile  b
where a.vid = b.vid and a.rdate = b.date and b.me >0 
group by  a.ex , nyse_size ,  BMR , refresh_date  , a.rdate , b.date ; 


***************************************************************************
*              returns
*************************************************************************** ;

proc sql ; 
create table ptfret as select distinct
a.ex , nyse_size ,  BMR , a.refresh_date , a.rdate , b.date, sum(w*ret) as ret
from w a , &retfile  b
where a.vid = b.vid and a.date = b.date
group by  a.ex , nyse_size ,  BMR , refresh_date  , a.rdate , b.date
order by  ex , nyse_size ,  BMR , refresh_date  , a.rdate , b.date ; 

create table ltg as select distinct
a.ex , nyse_size ,  BMR , a.refresh_date , a.rdate , b.rdate as date format yymmddn8., sum(w*medest)/sum(w)/100 as ltg
from w a , ind.msf_exp  b
where a.vid = b.vid and a.rdate = b.rdate
group by  a.ex , nyse_size ,  BMR , refresh_date  , a.rdate , b.rdate
order by  ex , nyse_size ,  BMR , refresh_date  , a.rdate , b.rdate ; 

drop view temprr2 ;
drop table dates ; 


***************************************************************************
*      Portfolios
*************************************************************************** ;

* ptfs ; 
data _SH ; set ptfret  ; where nyse_size = 1 and BMR = 3 ;  rename ret = SH  ; keep ex rdate date ret ; run ; 
data _BH ; set ptfret  ; where nyse_size = 2 and BMR = 3 ;  rename ret = BH  ; keep ex rdate date ret ; run ; 
data _SM ; set ptfret  ; where nyse_size = 1 and BMR = 2 ;  rename ret = SMed; keep ex rdate date ret ; run ; 
data _BM ; set ptfret  ; where nyse_size = 2 and BMR = 2 ;  rename ret = BMed; keep ex rdate date ret ; run ; 
data _SL ; set ptfret  ; where nyse_size = 1 and BMR = 1 ;  rename ret = SL  ; keep ex rdate date ret ; run ; 
data _BL ; set ptfret  ; where nyse_size = 2 and BMR = 1 ;  rename ret = BL  ; keep ex rdate date ret ; run ; 



data &xvar; 
merge _SH _BH _SL _BL _SM _BM; 
by ex rdate date ; 

if (SH+BH+SL+BL+SMed+BMed)^=. then do ; 

	&xvar     	 = (1/2)*(SH + BH)-(1/2)*(SL+BL); 
	&xvar._lc  	 = BH-BL ; 
	&xvar._sc  	 = SH-SL ; 
	&xvar._l   	 = (1/2)*(SH + BH); 
	&xvar._s      = (1/2)*(SL + BL);

	&xvar._l_sc   	 = SH ; 
	&xvar._s_sc      = SL ;
    &xvar._l_lc   	 = BH ; 
	&xvar._s_lc      = BL ;

	SMB    = (1/3)*(SH+SMed+SL)-(1/3)*(BH+BMed+BL); 

end ; 
drop SH BH SL BL SMed BMed; 

format &xvar &xvar._lc &xvar._sc &xvar._l &xvar._s SMB &xvar._l_sc &xvar._s_sc  &xvar._l_lc  &xvar._s_lc 11.6 ; 
run ; 


***************************************************************************
*      LTG Portfolios
*************************************************************************** ;

* ptfs ; 
data _SH_ltg ; set ltg  ; where nyse_size = 1 and BMR = 3 ;  rename ltg = SH  ; keep ex rdate date ltg ; run ; 
data _BH_ltg ; set ltg  ; where nyse_size = 2 and BMR = 3 ;  rename ltg = BH  ; keep ex rdate date ltg ; run ; 
data _SM_ltg ; set ltg  ; where nyse_size = 1 and BMR = 2 ;  rename ltg = SMed; keep ex rdate date ltg ; run ; 
data _BM_ltg ; set ltg  ; where nyse_size = 2 and BMR = 2 ;  rename ltg = BMed; keep ex rdate date ltg ; run ; 
data _SL_ltg ; set ltg  ; where nyse_size = 1 and BMR = 1 ;  rename ltg = SL  ; keep ex rdate date ltg ; run ; 
data _BL_ltg ; set ltg  ; where nyse_size = 2 and BMR = 1 ;  rename ltg = BL  ; keep ex rdate date ltg ; run ; 



data ltg_&xvar; 
merge _SH_ltg _BH_ltg _SL_ltg _BL_ltg _SM_ltg _BM_ltg; 
by ex rdate date ; 

if (SH+BH+SL+BL+SMed+BMed)^=. then do ; 

	&xvar     	 = (1/2)*(SH + BH)-(1/2)*(SL+BL); 
	&xvar._lc  	 = BH-BL ; 
	&xvar._sc  	 = SH-SL ; 
	&xvar._l   	 = (1/2)*(SH + BH); 
	&xvar._s      = (1/2)*(SL + BL);

	&xvar._l_sc   	 = SH ; 
	&xvar._s_sc      = SL ;
    &xvar._l_lc   	 = BH ; 
	&xvar._s_lc      = BL ;

	SMB    = (1/3)*(SH+SMed+SL)-(1/3)*(BH+BMed+BL); 

end ; 
drop SH BH SL BL SMed BMed; 

format &xvar &xvar._lc &xvar._sc &xvar._l &xvar._s SMB &xvar._l_sc &xvar._s_sc  &xvar._l_lc  &xvar._s_lc 11.6 ; 
run ; 





***************************************************************************
*     GLobal PTFs
*************************************************************************** ;


proc sql ; 
create table u as select distinct
a.* , lag_me / sum(lag_me) as wm format 9.6 from &xvar a , &fffile b
where a.ex = b.ex and a.date = b.date and a.date >= '31Jan1986'd  and lag_me >0
and &xvar ^=. 
group by a.rdate , a.date ; 




create table &xvar as select distinct
* from  &xvar union
select distinct 
'WOR' as ex format $6., rdate , date , 
sum(wm*&xvar) as &xvar format 11.6 , 
sum(wm*&xvar._lc) as &xvar._lc format 11.6 , 
sum(wm*&xvar._sc) as &xvar._sc format 11.6 , 
sum(wm*&xvar._l ) as &xvar._l  format 11.6 , 
sum(wm*&xvar._s ) as &xvar._s  format 11.6 , 

sum(wm*&xvar._l_sc ) as &xvar._l_sc  format 11.6 ,
sum(wm*&xvar._s_sc ) as &xvar._s_sc  format 11.6 ,
sum(wm*&xvar._l_lc ) as &xvar._l_lc  format 11.6 ,
sum(wm*&xvar._s_lc ) as &xvar._s_lc  format 11.6 ,

sum(wm*smb )      as smb       format 11.6 

from u group by rdate , date 

order by ex , rdate , date ; 


proc sql ; 
create table ltg_u as select distinct
a.* , lag_me / sum(lag_me) as wm format 9.6 from ltg_&xvar a , &fffile b
where a.ex = b.ex and a.date = b.date and a.date >= '31Jan1986'd  and lag_me >0
and &xvar ^=.  
group by a.rdate , a.date ; 

create table ltg_&xvar as select distinct
* from  ltg_&xvar union
select distinct 
'WOR' as ex format $6., rdate , date , 
sum(wm*&xvar) as &xvar format 11.6 , 
sum(wm*&xvar._lc) as &xvar._lc format 11.6 , 
sum(wm*&xvar._sc) as &xvar._sc format 11.6 , 
sum(wm*&xvar._l ) as &xvar._l  format 11.6 , 
sum(wm*&xvar._s ) as &xvar._s  format 11.6 , 

sum(wm*&xvar._l_sc ) as &xvar._l_sc  format 11.6 ,
sum(wm*&xvar._s_sc ) as &xvar._s_sc  format 11.6 ,
sum(wm*&xvar._l_lc ) as &xvar._l_lc  format 11.6 ,
sum(wm*&xvar._s_lc ) as &xvar._s_lc  format 11.6 ,

sum(wm*smb )      as smb       format 11.6 

from ltg_u group by rdate , date 

order by ex , rdate , date ; 

***************************************************************************
*     fill dates 
*************************************************************************** ;

proc sql ;
create table base as select distinct
ex , date from (select distinct ex from  &xvar) a , (select distinct date from  &fffile)
order by ex , date ;

data base ; 
merge base  &xvar;
by ex date ; 
run ;

proc sql ; 
create table base_2 as select distinct
ex , min(date) as date1 , max(date) as date2 from &xvar where &xvar ^=. group by ex ;

data &xvar ; merge base base_2 ; by ex ; 
if date1<= date<=date2 ; 
drop date1 date2 rdate ; 

%if &fill = 1 %then %do ; 
if &xvar     =. then &xvar = 0 ; 
if &xvar._lc =. then &xvar._lc = 0 ; 
if &xvar._sc =. then &xvar._sc = 0 ; 
if &xvar._l  =. then &xvar._l  = 0 ; 
if &xvar._s  =. then &xvar._s  = 0 ; 
if &xvar._l_sc  =. then &xvar._l_sc  = 0 ; 
if &xvar._s_sc  =. then &xvar._s_sc  = 0 ; 
if &xvar._l_lc  =. then &xvar._l_lc  = 0 ; 
if &xvar._s_lc  =. then &xvar._s_lc  = 0 ; 
if smb       =. then smb       = 0 ; 

%end ; 
run ; 
proc delete data = base base_2 ; run ;


***************************************************************************
*      drop variables 
*************************************************************************** ;
data &xvar;
set &xvar; 

%if &keeplc   = 0 %then %do ; drop &xvar._lc ; %end;
%if &keepsc   = 0 %then %do ; drop &xvar._sc ; %end;
%if &keepl    = 0 %then %do ; drop &xvar._l  ; %end;
%if &keeps    = 0 %then %do ; drop &xvar._s  ; %end;


%if &keep_all    = 0 %then %do ; drop &xvar._s_sc  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar._l_sc  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar._s_lc  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar._l_lc  ; %end;

%if &keepsmb     = 0 %then %do ; drop SMB       ; %end;

run ; 



***************************************************************************
*      keep weights 
*************************************************************************** ;

%if &keepw = 1 %then %do ; 

data _SH ; set w  ; where nyse_size = 1 and BMR = 3 ;  rename w = SH; keep ex vid date rdate w ; run ; 
data _BH ; set w  ; where nyse_size = 2 and BMR = 3 ;  rename w = BH; keep ex vid date rdate w ; run ; 
data _SM ; set w  ; where nyse_size = 1 and BMR = 2 ;  rename w = SMed; keep ex vid date rdate w ; run ; 
data _BM ; set w  ; where nyse_size = 2 and BMR = 2 ;  rename w = BMed; keep ex vid date rdate w ; run ; 
data _SL ; set w  ; where nyse_size = 1 and BMR = 1 ;  rename w = SL; keep ex vid date rdate w ; run ; 
data _BL ; set w  ; where nyse_size = 2 and BMR = 1 ;  rename w = BL; keep ex vid date rdate w ; run ; 



data &xvar._w;  
merge _SH _BH _SM _BM _SL _BL ; 
by vid rdate date ;
array X {6} SH BH SL BL SMed BMed ; 
do i = 1 to 6;
if X{i}=. then X{i} = 0 ; 
drop i ; 
end;

if (SH+BH+SL+BL)^=. then do ; 

	&xvar.w   	     = (1/2)*(SH + BH)-(1/2)*(SL+BL); 
	&xvar.w_lc  	 = BH-BL ; 
	&xvar.w_sc  	 = SH-SL ; 
	&xvar.w_l   	 = (1/2)*(SH + BH); 
	&xvar.w_s        = (1/2)*(SL + BL);

	&xvar.w_l_sc   	 = SH ; 
	&xvar.w_s_sc     = SL ;
    &xvar.w_l_lc   	 = BH ; 
	&xvar.w_s_lc     = BL ;

	smbw    = (1/3)*(SH+SMed+SL)-(1/3)*(BH+BMed+BL); 

end ; 
drop SH BH SL BL BMed SMed; 

format &xvar.w &xvar.w_lc &xvar.w_sc &xvar.w_l &xvar.w_s  &xvar.w_l_sc &xvar.w_s_sc &xvar.w_l_lc &xvar.w_s_lc smbw  9.3 ;


proc sql ; 
create table &xvar._w  as select distinct
a.vid , a.ex , a.rdate , a.date , a.* , wm from &xvar._w a left join U(keep = ex rdate date wm) b
on a.ex = b.ex and a.rdate = b.rdate and a.date = b.date ; 

data &xvar._w ; 
set  &xvar._w ; 
if wm^=. then &xvar.w_wor = &xvar.w*wm ; 
if wm^=. then &xvar.w_lc_wor = &xvar.w_lc*wm ; 
if wm^=. then &xvar.w_sc_wor = &xvar.w_sc*wm ; 
if wm^=. then &xvar.w_l_wor  = &xvar.w_l*wm ; 
if wm^=. then &xvar.w_s_wor  = &xvar.w_s*wm ; 

if wm^=. then &xvar.w_s_lc_wor  = &xvar.w_s_lc*wm ;
if wm^=. then &xvar.w_l_lc_wor  = &xvar.w_l_lc*wm ;
if wm^=. then &xvar.w_s_sc_wor  = &xvar.w_s_sc*wm ;
if wm^=. then &xvar.w_l_sc_wor  = &xvar.w_l_sc*wm ;

if wm^=. then smbw_wor  = smbw*wm ;

format &xvar.w_wor &xvar.w_lc_wor &xvar.w_sc_wor &xvar.w_l_wor &xvar.w_s_wor &xvar.w_s_lc_wor &xvar.w_l_lc_wor &xvar.w_s_sc_wor &xvar.w_l_sc_wor smbw_wor 9.3 ;

drop wm ; 

%if &keeplc = 0 %then %do ; drop &xvar.w_lc &xvar.w_lc_wor ; %end;
%if &keepsc = 0 %then %do ; drop &xvar.w_sc &xvar.w_sc_wor ; %end;
%if &keepl  = 0 %then %do ; drop &xvar.w_l  &xvar.w_l_wor  ; %end;
%if &keeps  = 0 %then %do ; drop &xvar.w_s  &xvar.w_s_wor  ; %end;

%if &keep_all    = 0 %then %do ; drop &xvar.w_s_sc_wor  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar.w_l_sc_wor  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar.w_s_lc_wor  ; %end;
%if &keep_all    = 0 %then %do ; drop &xvar.w_l_lc_wor  ; %end;

%if &keepsmb     = 0 %then %do ; drop smbw_wor       ; %end;

run ; 
%end ; 

***************************************************************************
*     House cleaning
*************************************************************************** ;
proc delete data = temprr _sl _sh ptfret _BH _BL _SM _BM nyse nyse2 nyseint  u; run ; 

%mend ; 

